
<div class="container">
    <div class="row">
        <div class="col-md-4 col-md-offset-4">
            <div class="login-panel panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">Only registered user can comment</h3>
                </div>
                <div class="panel-body">
                    <form method="post" action="{% url 'login' %}">
{% csrf_token %}

                        <p class="bs-component">
                            <table class="table table-condensed">
 							{{form}}
                            </table>
                        </p>
                        <p class="bs-component">
                            <center>
                                <input class="btn btn-success btn-sm" type="submit" value="login" />
                            </center>
                        </p>
                        <input type="hidden" name="next" value="{{next}}" />
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>