
.staractive{
	color: yellow;
}

#poll_vote a:hover{
	color: yellow;
	font-size: 2em;
    -webkit-transition: width 2s; /* Safari */
    transition: width 2s;
}

.user_comment_chart, .user_poll_chart{
	width: 80px; 
	height: 80px;
	display: inline-block;
	font-size: 16px;
}
